#
# spec file for package python-xdg
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define build_for_python3 0

Name:           python-xdg
%define         _name pyxdg
Summary:        Python library to use freedesktop.org specifications
License:        LGPL-2.1+
Group:          Development/Libraries/Python
Version:        0.25
Release:        12.2
Url:            http://freedesktop.org/Software/pyxdg
Source:         %{_name}-%{version}.tar.bz2
BuildRequires:  fdupes
%if %{build_for_python3}
BuildRequires:  python3
BuildRequires:  python3-devel
BuildRequires:  python3-distribute
Requires:       python3
%else
BuildRequires:  python-devel
%endif
%if !(%{build_for_python3})
# For old packman packages (only python2)
Provides:       python-pyxdg = %{version}
Obsoletes:      python-pyxdg < %{version}
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%if %{build_for_python3}
%define local_py_sitelib  %{python3_sitelib}
%define local_python      python3
%else
%define local_py_sitelib  %{python_sitelib}
%define local_python      %{__python}
%endif

%description
python-xdg (PyXDG) is a python library to use freedesktop.org
specifications.

%prep
%setup -q -n %{_name}-%{version}

%build
%{local_python} setup.py build

%install
%{local_python} setup.py install -O1 --skip-build --root="%{buildroot}" --prefix="%{_prefix}"
%fdupes %{buildroot}/%{local_py_sitelib}

%files
%defattr(-, root, root, 0755)
%doc AUTHORS ChangeLog COPYING README TODO
%{local_py_sitelib}/*.egg-info
%{local_py_sitelib}/xdg

%changelog
* Fri Apr 12 2013 toddrme2178@gmail.com
- Added requires and buildrequires python3.  It will not work
  properly without them on openSUSE < 12.3
- Cleanup macros
* Tue Jan 15 2013 vuntz@opensuse.org
- Drop use of %%py_requires (or equivalent for python3): a
  python(abi) Requires is automatically added.
* Tue Jan 15 2013 vuntz@opensuse.org
- Add pre_checkin.sh and rework python3 packaging so that only
  updating the python-xdg spec file is enough: the few differences
  between the two spec files are handled with a %%build_for_python3
  define.
* Mon Jan 14 2013 p.drouand@gmail.com
- Initial python3 support
* Mon Jan 14 2013 p.drouand@gmail.com
- Update to version 0.25:
  + Add support for $XDG_RUNTIME_DIR (deb#656338).
  + Allow desktop entry files that are not encoded in UTF-8
    (deb#693855).
  + Mime: Add support for subclasses and aliases.
- Changes from version 0.24:
  + Update allowed DesktopEntry categories following changes to the
    specification.
  + Fix removal of empty submenu (fdo#54747).
  + Documentation is now available on RTD:
    http://pyxdg.readthedocs.org/
  + A few more tests, and some code cleanup.
  + Fix failure to parse some menu files when kde-config is missing
    (fdo#56426).
- Changes from version 0.23:
  + Fix a test for non-UTF-8 locales.
- Changes from version 0.22:
  + Better unicode handling in several modules.
  + Fix for sorting non-ASCII menu entries (fdo#52492).
  + More tests.
- Changes from version 0.21:
  + Tests can now be run conveniently using nosetests, and cover
    more of the code.
  + BaseDirectory: New save_cache_path() function (fdo#26458).
  + Config: Default icon theme is 'hicolor', not 'highcolor'.
  + Menu: Obsolete Rule.compile() method removed.
  + DesktopEntry:
  - Corrected spelling of checkCategories() method (fdo#24974).
  - Consider Actions and Keywords keys standard.
  - Accept non-ASCII Keywords.
  - Update list of environments valid for OnlyShowIn.
  + Mime: Fix get_type_by_contents() in Python 3.
  + RecentFiles: Minor bug fixes.
- Changes from version 0.20:
  + Compatible with Python 3; requires Python 2.6 or later
  + Clean up accidental GPL license notice in Menu.py
  + Add test scripts for xdg.Mime, xdg.Locale and xdg.RecentFiles
  + Fixes for icon theme validation
  + Fix exception in xdg.Mime
  + Replace invalid string exceptions
  + Fall back to default base directories if $XDG* environment
    variables are set but empty.
  + Remove use of deprecated os.popen3 in Menu.py
  + Correct URLs in README
* Tue Oct 18 2011 vuntz@opensuse.org
- Add Provides/Obsoletes for python-pyxdg, which is the name of the
  package in Packman.
* Wed Jan 27 2010 vuntz@opensuse.org
- Update to version 0.19:
  + IniFile.py: add support for trusted desktop files
  + DesktopEntry.py: Support spec version 1.0, deb#563660
  + MimeType.py: Fix parsing of in memory data, deb#563718
  + DesktopEntry.py: Fix constructor, deb#551297, deb#562951,
    deb#562952
* Thu Dec 17 2009 vuntz@opensuse.org
- Update to version 0.18:
  + DesktopEntry.py: Add getMimeTypes() method, correctly returning
    strings
  + DesktopEntry.py: Deprecated getMimeType() returning list of regex
  + Menu.py: Add support for XDG_MENU_PREFIX
  + Mime.py: Add get_type_by_contents()
* Sun Aug  9 2009 coolo@novell.com
- use new python macros
* Fri May 22 2009 vuntz@novell.com
- Update to version 0.17:
  + Menu.py: Python <= 2.3 compatibility fix
  + DesktopEntry.py: Fix wrong indention
- Drop python-xdg-indentation.patch: fixed upstream.
- Use fdupes.
* Tue Dec  2 2008 riggwelter@opensuse.org
- Fix indentation problem in DesktopEntry
* Fri Oct 24 2008 lrupp@suse.de
- update to 0.16
  + IconTheme.py: Add more directories to the pixmap path
  + IniFile.py: Fix saving of relative filenames
  + IniFile.py, DesktopEntry.py: Fix __cmp__ method
  + IniFile.py, IconTheme.py: Better error handling
- avoid self-provides
- remove provides/obsoletes for non existing package
- cleanup in %%%%install is not necessary
* Fri Jul 25 2008 mauro@suse.de
- initial SUSE package
